@@ -124,7 +124,9 @@ def dir_content(
             else:
                 if not implicit_meta:
                     raise MD2FTError(
-                        f"No README.md in directory {file} while in explicit mode, add one with an 'ft:title' meta."
+                        f'No README.md in directory {file} while in explicit mode, ' 
+                         'Add README.md to directory or '
+                         'add "media_dir" value to ROOT README.md if directory contains images'
                     )
                 else:
                     # provide default value for directory description in implicit mode
